		------------------------------------
		-- Paragon Reputation 1.09 by Sev --
		------------------------------------
		
local vars = CreateFrame("FRAME") -- Variables
local faction = CreateFrame("FRAME") -- FactionName
local math = CreateFrame("FRAME") -- ReputationMath
local id = {} -- FactionID
local rep = {} -- FactionRep
local gain = {} -- FactionRepGain

faction:RegisterEvent("PLAYER_LOGIN"); -- RegisterLogin/Reload
math:RegisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE"); -- RegisterReputationMessage
vars:RegisterEvent("ADDON_LOADED"); --RegisterAddonLoad

		---------------------
		-- Load Variables --
		---------------------

vars:SetScript("OnEvent", function(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == "ParagonReputation" then
		if ParagonReputationDB == nil then
			ParagonReputationDB = {
				color = "|cff0088eeParagon Blue|r",
				text = "Paragon (0/10000)"
			}
		else
			if ParagonReputationDB.color == nil then
				ParagonReputationDB.color = "|cff0088eeParagon Blue|r"
			end
			if ParagonReputationDB.text == nil then
				ParagonReputationDB.text = "Paragon (0/10000)"
			end
		end
		paragon_panel()
	end
end)

		-----------------------
		-- Options by Ammako --
		-----------------------

function paragon_panel()
	local paragon_panel = CreateFrame("FRAME", "paragon_panel")
	paragon_panel.name = "Paragon Reputation"
	InterfaceOptions_AddCategory(paragon_panel)
	
	local title = paragon_panel:CreateFontString("Title", "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("|cff0088eeParagon|r Reputation |cff0088eev1.09|r")
	
	local subtext = paragon_panel:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subtext:SetPoint('TOPLEFT', title, 'BOTTOMLEFT', 1, -8)
	subtext:SetText("These options allow you to customize some settings of Paragon Reputation.")
	
	local labelcolor = paragon_panel:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	labelcolor:SetPoint('TOPLEFT', subtext, 'BOTTOMLEFT', 0, -8)
	labelcolor:SetText("|cffffd000Paragon Bars Color:|r")
	
	local colormenu = CreateFrame("FRAME", "colormenu", paragon_panel, "UIDropDownMenuTemplate")
	colormenu:SetPoint('TOPLEFT', labelcolor, 'BOTTOMLEFT', -18, -4)
	colormenu.initialize = function(dropdown)
		local sortMode = { "|cffbf4500Unfriendly Orange|r", "|cffe6b200Neutral Yellow|r", "|cff009919Default Green|r", "|cff0088eeParagon Blue|r", "|cffff40a0Lightish Red|r" }
		for i, mode in next, sortMode do
			local info = UIDropDownMenu_CreateInfo()
			info.text = sortMode[i]
			info.value = sortMode[i]
			info.func = function(self)
				ParagonReputationDB.color = self.value
				UIDropDownMenu_SetSelectedValue(dropdown, self.value)
			end
			UIDropDownMenu_AddButton(info)
		end
		UIDropDownMenu_SetSelectedValue(dropdown, ParagonReputationDB.color)
	end
	colormenu:HookScript("OnShow", colormenu.initialize)
	UIDropDownMenu_SetText(colormenu, ParagonReputationDB.color)
	UIDropDownMenu_SetWidth(colormenu, 130);
	
	local labeltext = paragon_panel:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	labeltext:SetPoint('TOPLEFT', subtext, 'BOTTOMLEFT', 160, -8)
	labeltext:SetText("|cffffd000Text Format:|r")
	
	local textmenu = CreateFrame("FRAME", "textmenu", paragon_panel, "UIDropDownMenuTemplate")
	textmenu:SetPoint('TOPLEFT', labeltext, 'BOTTOMLEFT', -18, -4)
	textmenu.initialize = function(dropdown)
		local sortMode = { "Paragon (0/10000)", "Exalted (0/10000)", "0 (0/10000)", "0/10000", "Reputation Deficit"}
		for i, mode in next, sortMode do
			local info = UIDropDownMenu_CreateInfo()
			info.text = sortMode[i]
			info.value = sortMode[i]
			info.func = function(self)
				ParagonReputationDB.text = self.value
				UIDropDownMenu_SetSelectedValue(dropdown, self.value)
			end
			UIDropDownMenu_AddButton(info)
		end
		UIDropDownMenu_SetSelectedValue(dropdown, ParagonReputationDB.text)
	end
	textmenu:HookScript("OnShow", textmenu.initialize)
	UIDropDownMenu_SetText(textmenu, ParagonReputationDB.text)	
	UIDropDownMenu_SetWidth(textmenu, 140);
end

		----------------------------------------
		-- Get Paragon Reputations and Values --
		----------------------------------------

faction:SetScript("OnEvent",function()
	local factionIndex = 1
	repeat
		local name, _, _, _, _, _, _, _, _, _, _, _, _, factionID = GetFactionInfo(factionIndex);
		if factionID and C_Reputation.IsFactionParagon(factionID) then
			local currentValue = C_Reputation.GetFactionParagonInfo(factionID);
			table.insert(faction,name)
			table.insert(id,factionID)
			table.insert(rep,currentValue)
			table.insert(gain,0)
		end
	factionIndex = factionIndex + 1
	until factionIndex > 200
end)

		-------------------------------
		-- Calculate Reputation Gain --
		-------------------------------

math:SetScript("OnEvent",function(_,_,msg,...)
	for n = 1, #faction do
		local msgrep = gsub(FACTION_STANDING_INCREASED_GENERIC,"%%s",faction[n]);
		if string.match(msgrep, msg) then
			local currentValue = C_Reputation.GetFactionParagonInfo(id[n]);
			gain[n] = currentValue - rep[n]
			rep[n] = rep[n] + gain[n]
		end
	end
end)

		--------------------------------
		-- Filter Reputation Messages --
		--------------------------------

ChatFrame_AddMessageEventFilter("CHAT_MSG_COMBAT_FACTION_CHANGE",function(_,_,msg,...)
	for n = 1, #faction do
		local msgrep = gsub(FACTION_STANDING_INCREASED_GENERIC,"%%s",faction[n]);
		if string.match(msgrep, msg) then
			msg=format(FACTION_STANDING_INCREASED,faction[n],gain[n])
		end
	end
	return false,msg,...
end)

		--------------------------------
		-- Localization for "Paragon" --
		--------------------------------
		
local LOCALE = GetLocale()
local l = {} -- "Paragon"

if LOCALE == "esES" or LOCALE == "esMX" then
	l = "Paragón" -- Spanish
elseif LOCALE == "zhCN" or LOCALE == "zhTW" then
	l = "巅峰" -- Chinese
elseif LOCALE == "itIT" then
	l = "Eccellenza" -- Italian
elseif LOCALE == "ptBR" then
	l = "Paragão" -- Portuguese
elseif LOCALE == "deDE" then
	l = "Huldigend" -- German
elseif LOCALE == "frFR" then
	l = "Parangon" -- French
elseif LOCALE == "ruRU" then
	l = "Идеал" -- Russian
elseif LOCALE == "koKR" then
	l = "불멸의 동맹" -- Korean
else
	l = "Paragon" -- English (DEFAULT)
end

		----------------------
		-- Reputation Frame --
		----------------------|

hooksecurefunc("ReputationFrame_Update", function(showLFGPulse)
	ReputationFrame.paragonFramesPool:ReleaseAll();
	local numFactions = GetNumFactions();
	local factionOffset = FauxScrollFrame_GetOffset(ReputationListScrollFrame);
	for i=1, NUM_FACTIONS_DISPLAYED, 1 do
		local factionIndex = factionOffset + i;
		local factionRow = _G["ReputationBar"..i];
		local factionBar = _G["ReputationBar"..i.."ReputationBar"];
		local factionStanding = _G["ReputationBar"..i.."ReputationBarFactionStanding"];
		if ( factionIndex <= numFactions ) then
			local _, _, _,_, _, _, _, _, _, _, _, _, _, factionID, _, _ = GetFactionInfo(factionIndex);
			if factionID and C_Reputation.IsFactionParagon(factionID) then
				local currentValue, threshold, _, hasRewardPending = C_Reputation.GetFactionParagonInfo(factionID);
				local value = mod(currentValue, threshold);
				if hasRewardPending then
					local paragonFrame = ReputationFrame.paragonFramesPool:Acquire();
					paragonFrame.factionID = factionID;
					paragonFrame:SetPoint("RIGHT", factionRow, 11, 0);
					paragonFrame.Glow:SetShown(hasRewardPending);
					paragonFrame.Check:SetShown(hasRewardPending);
					paragonFrame:Show();
					value = value + threshold
				end
				factionBar:SetMinMaxValues(0, threshold);
				if ParagonReputationDB.color == "|cff009919Default Green|r" then
					factionBar:SetStatusBarColor(0, .6, .1);
				elseif ParagonReputationDB.color == "|cffe6b200Neutral Yellow|r" then
					factionBar:SetStatusBarColor(.9, .7, 0);
				elseif ParagonReputationDB.color == "|cffbf4500Unfriendly Orange|r" then
					factionBar:SetStatusBarColor(.75, .27, 0);
				elseif ParagonReputationDB.color == "|cffff40a0Lightish Red|r" then
					factionBar:SetStatusBarColor(1, .25, .62);
				else
					factionBar:SetStatusBarColor(0, .5, .9);			
				end
				factionBar:SetValue(value);
				factionRow.rolloverText = HIGHLIGHT_FONT_COLOR_CODE.." "..format(REPUTATION_PROGRESS_FORMAT, value, threshold)..FONT_COLOR_CODE_CLOSE;
				if ParagonReputationDB.text == "Paragon (0/10000)" then
					factionStanding:SetText(l);
					factionRow.standingText = l;
				elseif ParagonReputationDB.text == "0 (0/10000)" then
					factionStanding:SetText(value);
					factionRow.standingText = value;
				elseif ParagonReputationDB.text == "0/10000" then
					factionStanding:SetText(" "..value.." / "..threshold);
					factionRow.standingText = (" "..value.." / "..threshold);
					factionRow.rolloverText = nil;
				elseif ParagonReputationDB.text == "Reputation Deficit" then
					if hasRewardPending then
						value = value - threshold
						factionStanding:SetText("+"..value);
						factionRow.standingText = "+"..value;
					else
						value = threshold - value
						factionStanding:SetText(value);
						factionRow.standingText = value;
					end
					factionRow.rolloverText = nil;
				end
			end
		else
			factionRow:Hide();
		end
	end
end)